=== modified file 'NEWS'
--- NEWS	2008-01-02 08:16:23 +0000
+++ NEWS	2008-01-02 15:49:06 +0000
@@ -120,6 +120,8 @@
     * Help topics can now be loaded from files. 
       (Ian Clatworthy, Alexander Belchenko)
 
+    * get_parent_map now always provides tuples as its output.  (Aaron Bentley)
+
     * Parent Providers should now implement ``get_parent_map`` returning a
       dictionary instead of ``get_parents`` returning a list.
       ``get_parents`` is now considered deprecated.  (John Arbash Meinel)

=== modified file 'bzrlib/repofmt/knitrepo.py'
--- bzrlib/repofmt/knitrepo.py	2007-12-30 02:13:10 +0000
+++ bzrlib/repofmt/knitrepo.py	2008-01-02 05:32:20 +0000
@@ -70,15 +70,16 @@
         parent_map = {}
         for revision_id in keys:
             if revision_id == _mod_revision.NULL_REVISION:
-                parent_map[revision_id] = []
+                parent_map[revision_id] = ()
             else:
                 try:
-                    parents = self._knit.get_parents_with_ghosts(revision_id)
+                    parents = tuple(
+                        self._knit.get_parents_with_ghosts(revision_id))
                 except errors.RevisionNotPresent:
                     continue
                 else:
                     if len(parents) == 0:
-                        parents = [_mod_revision.NULL_REVISION]
+                        parents = (_mod_revision.NULL_REVISION,)
                 parent_map[revision_id] = parents
         return parent_map
 

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2007-12-19 08:12:34 +0000
+++ bzrlib/repofmt/pack_repo.py	2008-01-02 05:32:20 +0000
@@ -1912,7 +1912,7 @@
         keys = set(keys)
         if _mod_revision.NULL_REVISION in keys:
             keys.discard(_mod_revision.NULL_REVISION)
-            found_parents = {_mod_revision.NULL_REVISION:[]}
+            found_parents = {_mod_revision.NULL_REVISION:()}
         else:
             found_parents = {}
         search_keys = set((revision_id,) for revision_id in keys)

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2007-12-25 06:02:32 +0000
+++ bzrlib/repository.py	2008-01-02 15:49:06 +0000
@@ -1697,15 +1697,17 @@
         parent_map = {}
         for revision_id in keys:
             if revision_id == _mod_revision.NULL_REVISION:
-                parent_map[revision_id] = []
+                parent_map[revision_id] = ()
             else:
                 try:
-                    parent_ids = self.get_revision(revision_id).parent_ids
+                    parent_id_list = self.get_revision(revision_id).parent_ids
                 except errors.NoSuchRevision:
                     pass
                 else:
-                    if len(parent_ids) == 0:
-                        parent_ids = [_mod_revision.NULL_REVISION]
+                    if len(parent_id_list) == 0:
+                        parent_ids = (_mod_revision.NULL_REVISION,)
+                    else:
+                        parent_ids = tuple(parent_id_list)
                     parent_map[revision_id] = parent_ids
         return parent_map
 

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2008-01-02 08:23:44 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2008-01-02 15:49:06 +0000
@@ -536,7 +536,18 @@
         graph = tree.branch.repository.get_graph()
         parents = graph.get_parent_map(['ghost', 'rev2'])
         self.assertTrue('ghost' not in parents)
-        self.assertEqual(tuple(parents['rev2']), ('rev1', 'ghost'))
+        self.assertEqual(parents['rev2'], ('rev1', 'ghost'))
+
+    def test_parent_map_type(self):
+        tree = self.make_branch_and_tree('here')
+        tree.lock_write()
+        self.addCleanup(tree.unlock)
+        tree.commit('initial commit', rev_id='rev1')
+        tree.commit('next commit', rev_id='rev2')
+        graph = tree.branch.repository.get_graph()
+        parents = graph.get_parent_map([NULL_REVISION, 'rev1', 'rev2'])
+        for value in parents.values():
+            self.assertIsInstance(value, tuple)
 
     def test_implements_revision_graph_can_have_wrong_parents(self):
         """All repositories should implement

